/*
 * Copyright (c) 2002-2003 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@

    Change History (most recent first):

$Log: mDNSPosix.h,v $
Revision 1.9  2003/10/30 19:25:19  cheshire
Fix warning on certain compilers

Revision 1.8  2003/08/12 19:56:26  cheshire
Update to APSL 2.0

Revision 1.7  2003/07/02 21:19:59  cheshire
<rdar://problem/3313413> Update copyright notices, etc., in source code comments

Revision 1.6  2003/03/13 03:46:21  cheshire
Fixes to make the code build on Linux

Revision 1.5  2003/03/08 00:35:56  cheshire
Switched to using new "mDNS_Execute" model (see "mDNSCore/Implementer Notes.txt")

Revision 1.4  2002/12/23 22:13:31  jgraessl

Reviewed by: Stuart Cheshire
Initial IPv6 support for mDNSResponder.

Revision 1.3  2002/09/21 20:44:53  zarzycki
Added APSL info

Revision 1.2  2002/09/19 04:20:44  cheshire
Remove high-ascii characters that confuse some systems

Revision 1.1  2002/09/17 06:24:34  cheshire
First checkin

*/

#ifndef __mDNSPlatformPosix_h
#define __mDNSPlatformPosix_h

#if (OEM_TARGET_OS != VXWORKS)
#include <sys/time.h>
#else
#include "sys/times.h"
#endif /* (OEM_TARGET_OS != VXWORKS) */

#if HAVE_IPV6
#define mDNSIPv6Support 1
#endif

#ifdef  __cplusplus
    extern "C" {
#endif

// This is a global because debugf_() needs to be able to check its value
extern int gMDNSPlatformPosixVerboseLevel;

#if (OEM_TARGET_OS == VXWORKS)
// servicesFlag bits
#define LPR_SERVICE_MASK         0x01
#define PORT9100_SERVICE_MASK    0x02
#define FTP_SERVICE_MASK         0x04
#define IPP_SERVICE_MASK         0x08
#define HTTP_SERVICE_MASK        0x10
//#define TELNET_SERVICE_MASK      0x20
//#define RIP_SERVICE_MASK         0x40
//one bit left
#define LPR_SERVICE_SHIFT        0
#define PORT9100_SERVICE_SHIFT   1
#define FTP_SERVICE_SHIFT        2
#define IPP_SERVICE_SHIFT        3
#define HTTP_SERVICE_SHIFT       4
//#define TELNET_SERVICE_SHIFT     5
//#define RIP_SERVICE_SHIFT        6

#define NOS_XEROX_SERVICES             5

typedef struct _tracked_NCL_vars_struct {
    bool IPConfiged;
    struct in_addr  ipAddr;
    char hostName[STR_HOST_LENGTH_XPM + 1];
    char domainName[STR_DOMAIN_LENGTH + 1];
    char deviceName[ID_NAME_LENGTH + 1];
    char uniquenessSuffix[18];  /* hex digits of Ethernet addr nn:nn:nn:nn:nn:nn */
    bool needUniquenessSuffix;  /* used to track service name changes */
    char perDeviceServiceRoot[ID_STR_LENGTH + 1]; //matches constant 256(noMDNS)
    int lenPerDeviceServiceRoot;
    bool mdnsEnabled;
    nuint8 servicesFlag;
    int lprServicePort;
    int port9100ServicePort;
    int ftpServicePort;
    int ippServicePort;
    int httpServicePort;
//    int telnetServicePort;
    char lprTxt[100];
    char port9100Txt[100];
    char ftpTxt[100];
    char ippTxt[150];
    char httpTxt[100];
//    char telnetTxt[100];
    char commonTxt[512];
    char printerLocation[ID_STR_LENGTH_XPM + 1];
    domainlabel renamedService;       // version 26_2+ potentially unused
} trackedNCLvarsStruct;
#endif /* (OEM_TARGET_OS == VXWORKS) */
struct mDNS_PlatformSupport_struct
	{
    // No additional data required for Posix at this time
#if (OEM_TARGET_OS != VXWORKS)
        long dummy[1];  // Some compilers don't like empty structures
#else
    // The following parameters must be set up by the client before 
    // calling mDNS_Init, which in turn calls mDNSPlatformInit.

    const char *    pRichTextHostName;  // Rich text host name
    const char *    pProgramName;
    
    // The following are set up by mDNSPlatformInit itself.
    
	SEM_ID					lockID;
	SEM_ID					readyEvent;
	SEM_ID					quitEvent;
	int					commandPipe;
	int					task;
	long					configID;
	trackedNCLvarsStruct trackedNCLvars;
#endif /* (OEM_TARGET_OS != VXWORKS) */
	};

extern mStatus mDNSPlatformPosixRefreshInterfaceList(mDNS *const m);
    // See comment in implementation.

// Call mDNSPosixGetFDSet before calling select(), to update the parameters
// as may be necessary to meet the needs of the mDNSCore code.
// The timeout pointer MUST NOT be NULL.
// Set timeout->tv_sec to 0x3FFFFFFF if you want to have effectively no timeout
// After calling mDNSPosixGetFDSet(), call select(nfds, &readfds, NULL, NULL, &timeout); as usual
// After select() returns, call mDNSPosixProcessFDSet() to let mDNSCore do its work
extern void mDNSPosixGetFDSet(mDNS *const m, int *nfds, fd_set *readfds, struct timeval *timeout);
#if (OEM_TARGET_OS != VXWORKS)
extern void mDNSPosixProcessFDSet(mDNS *const m, fd_set *readfds);
#else
extern int mDNSPosixProcessFDSet(mDNS *const m, int selectresult, fd_set *readfds);


extern void examineNvvarsNP(const char *name, ParamStatus status, void *info);
extern void examineNvvars(int nclSubject, mDNS_PlatformSupport *platform, mDNS *m0);
extern void linkChangeNotified(mDNS *const m, int state);
#endif /* (OEM_TARGET_OS != VXWORKS) */

#ifdef  __cplusplus
    }
#endif

#endif
